import React, { useState } from "react";
import classNames from "classnames";

import { addAnnouncement } from "actions/announcements";
import Button from "components/Button";
import { useActionLoading } from "hooks";

const urlRegex = /https?:\/\/(www\.)?[-a-zA-Z0-9@:%._+~#=]{1,256}\.[a-zA-Z0-9()]{1,6}\b([-a-zA-Z0-9()@:%_+.~#?&//=]*)/;

const AddAnnouncementForm = ({ className }) => {
  const [text, setText] = useState("");
  const [link, setLink] = useState("");
  const [linkValid, setLinkValid] = useState(false);
  const [type, setType] = useState("announcement");

  const addingAnnouncement = useActionLoading(addAnnouncement, {
    content: text,
    link,
    type,
  });

  const onTextInput = (evt) => {
    setText(evt.target.value);
  };

  const onLinkInput = (evt) => {
    setLink(evt.target.value);

    if (!!evt.target.value) {
      setLinkValid(evt.target.value.match(urlRegex));
    }
  };

  const onAdd = async (evt) => {
    if (!!text) {
      const result = await addAnnouncement.run({ content: text, link, type });

      if (!result.error) {
        setText("");
        setLink("");
      }
    }
  };

  return (
    <div className={className}>
      <div className="grid grid-cols-1 gap-4">
        <div
          className="form-field"
          onChange={(evt) => setType(evt.target.value)}
        >
          <div className="form-field__wrapper text-sm">
            <div className="radio form-field__control">
              <label>
                <input
                  type="radio"
                  name="type"
                  value="announcement"
                  defaultChecked
                />
                <span>Oznámení</span>
              </label>
            </div>

            <div className="radio form-field__control">
              <label>
                <input type="radio" name="type" value="voting" />
                <span>Rozhodující hlasování</span>
              </label>
            </div>
          </div>
        </div>

        <div className="form-field">
          <div className="form-field__wrapper form-field__wrapper--shadowed">
            <textarea
              className="text-input text-sm form-field__control "
              value={text}
              rows="3"
              cols="40"
              placeholder="Vyplňte text oznámení"
              onChange={onTextInput}
            ></textarea>
          </div>
        </div>

        <div
          className={classNames("form-field", {
            hidden: type !== "voting",
            "form-field--error": !!link && !linkValid,
          })}
        >
          <div className="form-field__wrapper form-field__wrapper--shadowed">
            <input
              type="text"
              className="text-input text-sm text-input--has-addon-l form-field__control"
              value={link}
              placeholder="URL hlasování"
              onChange={onLinkInput}
            />
            <div className="text-input-addon text-input-addon--l order-first">
              <i className="ico--link1"></i>
            </div>
          </div>
          {!!link && !linkValid && (
            <div className="form-field__error">Zadejte platnou URL.</div>
          )}
        </div>
      </div>

      <Button
        onClick={onAdd}
        className="text-sm mt-4"
        hoverActive
        loading={addingAnnouncement}
        disabled={
          !text || (type === "voting" && !linkValid) || addingAnnouncement
        }
      >
        Přidat oznámení
      </Button>
    </div>
  );
};

export default AddAnnouncementForm;
